@@ -1,5 +1,5 @@
 `ddst.phi` <-
 function(x, j, base = ddst.base.legendre) {
-  .Internal(mean(base(x,j)))
+  mean(base(x,j))
 }
 
